package com.ruoyi.learn.service;

import java.util.List;
import com.ruoyi.learn.domain.LearnExaminee;

/**
 * 答卷Service接口
 * 
 * @author ruoyi
 * @date 2025-09-25
 */
public interface ILearnExamineeService 
{
    /**
     * 查询答卷
     * 
     * @param examineeId 答卷主键
     * @return 答卷
     */
    public LearnExaminee selectLearnExamineeByExamineeId(Long examineeId);

    /**
     * 查询答卷列表
     * 
     * @param learnExaminee 答卷
     * @return 答卷集合
     */
    public List<LearnExaminee> selectLearnExamineeList(LearnExaminee learnExaminee);

    /**
     * 新增答卷
     * 
     * @param learnExaminee 答卷
     * @return 结果
     */
    public int insertLearnExaminee(LearnExaminee learnExaminee);

    /**
     * 修改答卷
     * 
     * @param learnExaminee 答卷
     * @return 结果
     */
    public int updateLearnExaminee(LearnExaminee learnExaminee);

    /**
     * 批量删除答卷
     * 
     * @param examineeIds 需要删除的答卷主键集合
     * @return 结果
     */
    public int deleteLearnExamineeByExamineeIds(Long[] examineeIds);

    /**
     * 删除答卷信息
     * 
     * @param examineeId 答卷主键
     * @return 结果
     */
    public int deleteLearnExamineeByExamineeId(Long examineeId);
}
